Tutorials
===========

To get started using the package, we recommend going through the tutorials in the order
listed below. Each tutorial is also a Jupyter notebook which you can download and run
locally.

.. toctree::
   :maxdepth: 1
   :caption: Tutorials

   tutorials/introductory_tutorial.ipynb
   tutorials/filter_corpus_using_quality.ipynb
   tutorials/sklearn_integration.ipynb

